@@ -43,6 +43,7 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #define X_AppleWMSetWindowLevel		9
 #define X_AppleWMSetCanQuit		10
 #define X_AppleWMSetWindowMenu		11
+#define X_AppleWMSendPSN		12
 
 /* Events */
 #define AppleWMControllerNotify		0
@@ -157,6 +158,8 @@ Bool XAppleWMSetFrontProcess (Display *dpy);
 
 Bool XAppleWMSetWindowLevel (Display *dpy, Window id, int level);
 
+Bool XAppleWMSendPSN(Display *dpy);
+
 Bool XAppleWMSetCanQuit (Display *dpy, Bool state);
 
 Bool XAppleWMFrameGetRect (Display *dpy,
